==> computer-1.1.0.tar.gz: lib/src/compute_api/worker.dart <==
import 'dart:async';
import 'dart:isolate';

import 'package:computer/src/errors.dart';
import 'package:meta/meta.dart';

import 'task.dart';

typedef OnResultCallback = void Function(TaskResult result, Worker worker);
typedef OnErrorCallback = void Function(RemoteExecutionError error, Worker worker);

enum WorkerStatus { idle, processing }

class IsolateInitParams {
  SendPort sendPort;

  IsolateInitParams({@required this.sendPort});
}

class Worker {
  final String name;

  WorkerStatus status = WorkerStatus.idle;

  Isolate _isolate;
  SendPort _sendPort;
  ReceivePort _receivePort;
  Stream _broadcastReceivePort;

  StreamSubscription _broadcastPortSubscription;

  Worker(this.name);

  Future<void> init({
    @required OnResultCallback onResult,
    @required OnErrorCallback onError,
  }) async {
    _receivePort = ReceivePort();

    _isolate = await Isolate.spawn(
      isolateEntryPoint,
      IsolateInitParams(
        sendPort: _receivePort.sendPort,
      ),
      debugName: name,
      errorsAreFatal: false,
    );

    _broadcastReceivePort = _receivePort.asBroadcastStream();

    _sendPort = await _broadcastReceivePort.first;

    _broadcastPortSubscription = _broadcastReceivePort.listen((res) {
      status = WorkerStatus.idle;
      if (res is RemoteExecutionError) {
        onError(res, this);
        return;
      }
      onResult(res, this);
    });
  }

  void execute(Task task) {
    status = WorkerStatus.processing;
    _sendPort.send(task);
  }

  Future<void> dispose() async {
    await _broadcastPortSubscription.cancel();
    _isolate.kill();
    _receivePort.close();
  }
}

Future<void> isolateEntryPoint(IsolateInitParams params) async {
  final receivePort = ReceivePort();
  final sendPort = params.sendPort;

  sendPort.send(receivePort.sendPort);

  await for (final Task task in receivePort) {
    try {
      final shouldPassParam = task.param != null;

      final computationResult = shouldPassParam ? await task.task(task.param) : await task.task();

      final result = TaskResult(
        result: computationResult,
        capability: task.capability,
      );
      sendPort.send(result);
    } catch (error) {
      sendPort.send(RemoteExecutionError(error.toString(), task.capability));
    }
  }
}

==> computer-1.1.1.tar.gz: lib/src/compute_api/worker.dart <==
import 'dart:async';
import 'dart:isolate';

import 'package:computer/src/errors.dart';
import 'package:meta/meta.dart';

import 'task.dart';

typedef OnResultCallback = void Function(
  TaskResult result,
  Worker worker,
);

typedef OnErrorCallback = void Function(
  RemoteExecutionError error,
  Worker worker,
);

enum WorkerStatus { idle, processing }

class IsolateInitParams {
  SendPort sendPort;

  IsolateInitParams({@required this.sendPort});
}

class Worker {
  final String name;

  WorkerStatus status = WorkerStatus.idle;

  Isolate _isolate;
  SendPort _sendPort;
  ReceivePort _receivePort;
  Stream _broadcastReceivePort;

  StreamSubscription _broadcastPortSubscription;

  Worker(this.name);

  Future<void> init({
    @required OnResultCallback onResult,
    @required OnErrorCallback onError,
  }) async {
    _receivePort = ReceivePort();

    _isolate = await Isolate.spawn(
      isolateEntryPoint,
      IsolateInitParams(
        sendPort: _receivePort.sendPort,
      ),
      debugName: name,
      errorsAreFatal: false,
    );

    _broadcastReceivePort = _receivePort.asBroadcastStream();

    _sendPort = await _broadcastReceivePort.first;

    _broadcastPortSubscription = _broadcastReceivePort.listen((res) {
      status = WorkerStatus.idle;
      if (res is RemoteExecutionError) {
        onError(res, this);
        return;
      }
      onResult(res, this);
    });
  }

  void execute(Task task) {
    status = WorkerStatus.processing;
    _sendPort.send(task);
  }

  Future<void> dispose() async {
    await _broadcastPortSubscription.cancel();
    _isolate.kill();
    _receivePort.close();
  }
}

Future<void> isolateEntryPoint(IsolateInitParams params) async {
  final receivePort = ReceivePort();
  final sendPort = params.sendPort;

  sendPort.send(receivePort.sendPort);

  await for (final Task task in receivePort) {
    try {
      final shouldPassParam = task.param != null;

      final computationResult =
          shouldPassParam ? await task.task(task.param) : await task.task();

      final result = TaskResult(
        result: computationResult,
        capability: task.capability,
      );
      sendPort.send(result);
    } catch (error) {
      sendPort.send(RemoteExecutionError(error.toString(), task.capability));
    }
  }
}
